@@ -147,26 +147,3 @@ void zathura_adjustment_set_value(GtkAdjustment* adjustment, gdouble value) {
 
   gtk_adjustment_set_value(adjustment, MAX(lower, MIN(upper_m_size, value)));
 }
-
-gdouble zathura_adjustment_get_ratio(GtkAdjustment* adjustment) {
-  gdouble lower     = gtk_adjustment_get_lower(adjustment);
-  gdouble upper     = gtk_adjustment_get_upper(adjustment);
-  gdouble page_size = gtk_adjustment_get_page_size(adjustment);
-  gdouble value     = gtk_adjustment_get_value(adjustment);
-
-  return (value - lower + page_size / 2.0) / (upper - lower);
-}
-
-void zathura_adjustment_set_value_from_ratio(GtkAdjustment* adjustment, gdouble ratio) {
-  if (ratio == 0.0) {
-    return;
-  }
-
-  gdouble lower     = gtk_adjustment_get_lower(adjustment);
-  gdouble upper     = gtk_adjustment_get_upper(adjustment);
-  gdouble page_size = gtk_adjustment_get_page_size(adjustment);
-
-  gdouble value = (upper - lower) * ratio + lower - page_size / 2.0;
-
-  zathura_adjustment_set_value(adjustment, value);
-}
