@@ -15,6 +15,7 @@
 #include "zathura.h"
 #include "render.h"
 #include "document.h"
+#include "document-widget.h"
 #include "utils.h"
 #include "shortcuts.h"
 #include "page-widget.h"
@@ -97,7 +98,7 @@ void cb_view_hadjustment_value_changed(GtkAdjustment* adjustment, gpointer data)
   update_visible_pages(zathura);
 
   zathura_document_t* document = zathura_get_document(zathura);
-  const double position_x      = zathura_adjustment_get_ratio(adjustment);
+  const double position_x      = zathura_document_widget_get_ratio(zathura, adjustment, true);
   const double position_y      = zathura_document_get_position_y(document);
   unsigned int page_id         = position_to_page_number(document, position_x, position_y);
 
@@ -123,7 +124,7 @@ void cb_view_vadjustment_value_changed(GtkAdjustment* adjustment, gpointer data)
 
   zathura_document_t* document = zathura_get_document(zathura);
   const double position_x      = zathura_document_get_position_x(document);
-  const double position_y      = zathura_adjustment_get_ratio(adjustment);
+  const double position_y      = zathura_document_widget_get_ratio(zathura, adjustment, false);
   const unsigned int page_id   = position_to_page_number(document, position_x, position_y);
 
   zathura_document_set_position_x(document, position_x);
@@ -158,7 +159,8 @@ static void cb_view_adjustment_changed(GtkAdjustment* adjustment, zathura_t* zat
   /* reset the adjustment, in case bounds have changed */
   const double ratio =
       width == true ? zathura_document_get_position_x(document) : zathura_document_get_position_y(document);
-  zathura_adjustment_set_value_from_ratio(adjustment, ratio);
+
+  zathura_document_widget_set_value_from_ratio(zathura, adjustment, ratio, width);
 }
 
 void cb_view_hadjustment_changed(GtkAdjustment* adjustment, gpointer data) {
@@ -203,8 +205,8 @@ void cb_refresh_view(GtkWidget* GIRARA_UNUSED(view), gpointer data) {
   const double position_x = zathura_document_get_position_x(document);
   const double position_y = zathura_document_get_position_y(document);
 
-  zathura_adjustment_set_value_from_ratio(vadj, position_y);
-  zathura_adjustment_set_value_from_ratio(hadj, position_x);
+  zathura_document_widget_set_value_from_ratio(zathura, vadj, position_y, false);
+  zathura_document_widget_set_value_from_ratio(zathura, hadj, position_x, true);
 
   statusbar_page_number_update(zathura);
 }
@@ -318,8 +320,8 @@ void cb_page_layout_value_changed(girara_session_t* session, const char* name, g
   bool page_right_to_left = false;
   girara_setting_get(zathura->ui.session, "page-right-to-left", &page_right_to_left);
 
-  page_widget_set_mode(zathura, page_padding, pages_per_row, first_page_column, page_right_to_left);
   zathura_document_set_page_layout(zathura_get_document(zathura), page_padding, pages_per_row, first_page_column);
+  zathura_document_widget_set_mode(zathura, page_padding, pages_per_row, first_page_column, page_right_to_left);
 }
 
 void cb_index_row_activated(GtkTreeView* tree_view, GtkTreePath* path, GtkTreeViewColumn* UNUSED(column), void* data) {
