@@ -7,18 +7,14 @@
 #include <glib-unix.h>
 #endif
 
-struct zathura_signalfilemonitor_s
-{
+struct zathura_signalfilemonitor_s {
   ZathuraFileMonitor parent;
-  gint               handle;
+  gint handle;
 };
 
-G_DEFINE_TYPE(ZathuraSignalFileMonitor, zathura_signalfilemonitor,
-              ZATHURA_TYPE_FILEMONITOR)
+G_DEFINE_TYPE(ZathuraSignalFileMonitor, zathura_signalfilemonitor, ZATHURA_TYPE_FILEMONITOR)
 
-static gboolean
-signal_handler(gpointer data)
-{
+static gboolean signal_handler(gpointer data) {
   if (data == NULL) {
     return TRUE;
   }
@@ -31,24 +27,17 @@ signal_handler(gpointer data)
   return TRUE;
 }
 
-static void
-start(ZathuraFileMonitor* file_monitor)
-{
+static void start(ZathuraFileMonitor* file_monitor) {
 #ifdef G_OS_UNIX
-  ZathuraSignalFileMonitor* signal_file_monitor =
-    ZATHURA_SIGNALFILEMONITOR(file_monitor);
+  ZathuraSignalFileMonitor* signal_file_monitor = ZATHURA_SIGNALFILEMONITOR(file_monitor);
 
-  signal_file_monitor->handle =
-    g_unix_signal_add(SIGHUP, signal_handler, signal_file_monitor);
+  signal_file_monitor->handle = g_unix_signal_add(SIGHUP, signal_handler, signal_file_monitor);
 #endif
 }
 
-static void
-stop(ZathuraFileMonitor* file_monitor)
-{
+static void stop(ZathuraFileMonitor* file_monitor) {
 #ifdef G_OS_UNIX
-  ZathuraSignalFileMonitor* signal_file_monitor =
-    ZATHURA_SIGNALFILEMONITOR(file_monitor);
+  ZathuraSignalFileMonitor* signal_file_monitor = ZATHURA_SIGNALFILEMONITOR(file_monitor);
 
   if (signal_file_monitor->handle > 0) {
     g_source_remove(signal_file_monitor->handle);
@@ -57,17 +46,13 @@ stop(ZathuraFileMonitor* file_monitor)
 #endif
 }
 
-static void
-zathura_signalfilemonitor_finalize(GObject* object)
-{
+static void zathura_signalfilemonitor_finalize(GObject* object) {
   stop(ZATHURA_FILEMONITOR(object));
 
   G_OBJECT_CLASS(zathura_signalfilemonitor_parent_class)->finalize(object);
 }
 
-static void
-zathura_signalfilemonitor_class_init(ZathuraSignalFileMonitorClass* class)
-{
+static void zathura_signalfilemonitor_class_init(ZathuraSignalFileMonitorClass* class) {
   ZathuraFileMonitorClass* filemonitor_class = ZATHURA_FILEMONITOR_CLASS(class);
   filemonitor_class->start                   = start;
   filemonitor_class->stop                    = stop;
@@ -76,8 +61,6 @@ zathura_signalfilemonitor_class_init(ZathuraSignalFileMonitorClass* class)
   object_class->finalize     = zathura_signalfilemonitor_finalize;
 }
 
-static void
-zathura_signalfilemonitor_init(ZathuraSignalFileMonitor* signalfilemonitor)
-{
+static void zathura_signalfilemonitor_init(ZathuraSignalFileMonitor* signalfilemonitor) {
   signalfilemonitor->handle = 0;
 }
