@@ -9,17 +9,15 @@
 /**
  * Zathura password dialog
  */
-typedef struct zathura_password_dialog_info_s
-{
-  char* path; /**< Path to the file */
-  char* uri; /**< URI to the file */
-  zathura_t* zathura;  /**< Zathura session */
+typedef struct zathura_password_dialog_info_s {
+  char* path;         /**< Path to the file */
+  char* uri;          /**< URI to the file */
+  zathura_t* zathura; /**< Zathura session */
 } zathura_password_dialog_info_t;
 
-struct zathura_document_information_entry_s
-{
+struct zathura_document_information_entry_s {
   zathura_document_information_type_t type; /**< Type of the information */
-  char* value; /**< Value */
+  char* value;                              /**< Value */
 };
 
 /**
